<a href="{% url 'plugins:netbox_tenant_group_permissions_synchronization:device_permissions_sync' device_id=device.id %}"
   class="btn btn-sm btn-primary">
  <i class="mdi mdi-sync"></i> Sync Tenant Group Permissions
</a>
